Debug mode provides developers with detailed information about errors happening in their code.
It displays tracebacks, metadata about the environment, and currently defined Django settings.

This is useful when developing, but gives the attacker information about the used `Django` & `Python`  
versions to match against CVEs, and access to source code snippets, internal file paths, some variables and their values.